@@ -22,7 +22,7 @@ use Travel::Status::DE::HAFAS::Product;
 use Travel::Status::DE::HAFAS::Services;
 use Travel::Status::DE::HAFAS::StopFinder;
 
-our $VERSION = '6.11';
+our $VERSION = '6.12';
 
 # {{{ Endpoint Definition
 
@@ -406,7 +406,9 @@ sub post_with_cache {
 
 	if ($cache) {
 		my $content = $cache->thaw( $self->{post} );
-		if ($content) {
+		if ( $content
+			and not $content =~ m{ CGI_NO_SERVER | CGI_READ_FAILED }x )
+		{
 			if ( $self->{developer_mode} ) {
 				say '  cache hit';
 			}
@@ -890,7 +892,7 @@ monitors
 
 =head1 VERSION
 
-version 6.11
+version 6.12
 
 =head1 DESCRIPTION
 
